nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Event

Enum Event 

#[repr(u8)]
pub enum Event { NORMAL_MODE = 0, IBI = 1, MASTER_REQUEST = 2, HOT_JOIN_REQUEST = 3, }

Variants



NORMAL_MODE = 0

NORMAL_MODE: If EVENT is set to 0 after was a non-0 value, event processing will cancel if the event processing has not yet started; if event processing has already been started, then event processing will not be be cancelled.



IBI = 1

IBI: Start an In-Band Interrupt. This will try to push an IBI interrupt onto the I3C bus. If data is associated with the IBI, then the data will be read from the SCTRL.IBIDATA field. If time control is enabled, then this data will also include any time control-related bytes; additionally, the IBIDATA byte will have bit 7 set to 1 automatically (as is required for time control). The IBI interrupt will occur after the 1st (mandatory) IBIDATA, if any.



MASTER_REQUEST = 2

MASTER_REQUEST: Start a Master-Request.



HOT_JOIN_REQUEST = 3

HOT_JOIN_REQUEST: Start a Hot-Join request. A Hot-Join Request should only be used when the device is powered on after the I3C bus is already powered up, or when the device is connected using hot insertion methods (the device is powered up when it is physically inserted onto the powered-up I3C bus). The hot join will wait for Bus Idle, and SCTRL.EVENT=HOT_JOIN_REQUEST must be set before the slave enable (SCONFIG.SLVENA).

Implementations

Source

impl Event

pub const fn from_bits(val: u8) -> Event

pub const fn to_bits(self) -> u8