#[repr(u8)]pub enum Ibiresp {
ACK = 0,
NACK = 1,
ACK_WITH_MANDATORY = 2,
MANUAL = 3,
}Variants
ACK = 0
ACK: Acknowledge. A mandatory byte (or not) is decided by the Master In-band Interrupt Registry and Rules Register (MIBIRULES). To limit the maximum number of IBI bytes, configure the Read Termination field (MCTRL.RDTERM).
NACK = 1
NACK: Not acknowledge
ACK_WITH_MANDATORY = 2
ACK_WITH_MANDATORY: Acknowledge with mandatory byte (ignores the MIBIRULES register). Acknowledge with mandatory byte should not be used, unless only slaves with a mandatory byte can cause an In-Band Interrupt.
MANUAL = 3
MANUAL: stop and wait for a decision using the IBIAckNack request
Implementations