nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Mstena

Enum Mstena 

#[repr(u8)]
pub enum Mstena { MASTER_OFF = 0, MASTER_ON = 1, MASTER_CAPABLE = 2, _RESERVED_3 = 3, }

Variants



MASTER_OFF = 0

MASTER_OFF: Master is off (is not enabled). If MASTER_OFF is enabled, then the I3C module can only use slave mode.



MASTER_ON = 1

MASTER_ON: Master is on (is enabled). When used from start-up, this I3C module is master by default (the main master). The module will control the bus unless the master is handed off. If the master is handed off, then MSTENA must move to 2 after that happens. The handoff means emitting GETACCMST and if accepted, the module will emit a STOP and set the MSTENA bit to 2 (or 0).



MASTER_CAPABLE = 2

MASTER_CAPABLE: The I3C module is master-capable; however the module is operating as a slave now. When used from the start, the I3C module will start as a slave, but will be prepared to switch to master mode. To switch to master mode, the slave emits an Master Request (MR), or gets a GETACCMST CCC command and accepts it (to switch on the STOP).



_RESERVED_3 = 3

Implementations

Source

impl Mstena

pub const fn from_bits(val: u8) -> Mstena

pub const fn to_bits(self) -> u8