nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Request

Enum Request 

#[repr(u8)]
pub enum Request { NONE = 0, EMITSTARTADDR = 1, EMITSTOP = 2, IBIACKNACK = 3, PROCESSDAA = 4, _RESERVED_5 = 5, FORCEEXIT = 6, AUTOIBI = 7, }

Variants



NONE = 0

NONE: Returns to this when finished with any request. The MSTATUS register indicates the master’s state. See also AutoIBI mode. NONE is only written as 0: when setting RDTERM to 1 (to stop a read in progress) or when setting IBI reponse field (IBIRESP) for MSG use



EMITSTARTADDR = 1

EMITSTARTADDR: Emit START with address and direction from a stopped state or in the middle of a Single Data Rate (SDR) message. If from a stopped state (IDLE), then emit start may be prevented by an event (like IBI, MR, HJ), in which case the appropriate interrupt is signaled; note that Emit START can be resubmitted.



EMITSTOP = 2

EMITSTOP: Emit a STOP on bus. Must be in Single Data Rate (SDR) mode. If in Dynamic Address Assignment (DAA) mode, Emit stop will exit DAA mode.



IBIACKNACK = 3

IBIACKNACK: Manual In-Band Interrupt (IBI) Acknowledge (ACK) or Not Acknowledge (NACK). When IBIRESP has indicated a hold on an In-Band Interrupt to allow a manual decision, this request completes it. Uses IBIRESP to provide the information.



PROCESSDAA = 4

PROCESSDAA: If not in Dynamic Address Assignment (DAA) mode now, will issue START, 7E, ENTDAA, and then will emit 7E/R to process each slave. Will stop just before the new Dynamic Address (DA) is to be emitted. The next Process DAA request will use the Addr field as the new DA to assign. If NACKed on the 7E/R, then the interrupt will indicate this situation, and a STOP will be emitted.



_RESERVED_5 = 5



FORCEEXIT = 6

FORCEEXIT and IBHR: Emit an Exit Pattern from any state, but end Double Data Rate (DDR) (including MSGDDR), if in DDR mode now. Includes a STOP afterward. If TYPE != 0, then it will perform an IBHR (In-Band Hardware Reset). If TYPE=2, then it does a normal reset (DEFRST can prevent the reset). If TYPE=3, it does a forced reset (will always reset).



AUTOIBI = 7

AUTOIBI: Hold in a stopped state, but auto-emit START,7E when the slave is holding down SDA to get an In-Band Interrupt (IBI). Actual In-Band Interrupt handling is defined by IBIRESP.

Implementations

Source

impl Request

pub const fn from_bits(val: u8) -> Request

pub const fn to_bits(self) -> u8